pub enum CoinSelectionAlgorithm {
BranchAndBound,
LargestFirst,
OldestFirst,
SingleRandomDraw,
}Expand description
Coin selection algorithm to use when creating a transaction.
Variants
BranchAndBound
Branch and bound with single random draw fallback.
LargestFirst
Select largest UTXOs first until the target is reached.
OldestFirst
Select oldest local UTXOs first until the target is reached.
SingleRandomDraw
Shuffle optional UTXOs and select randomly until the target is reached.