Enum TxOrdering

pub enum TxOrdering {
    Shuffle,
    Untouched,
}
Ordering of the transaction’s inputs and outputs.

Variants



Shuffle

Randomized (default)



Untouched

Untouched

Untouched insertion order for recipients and for manually added UTXOs. This guarantees all recipients preserve insertion order in the transaction’s output vector and manually added UTXOs preserve insertion order in the transaction’s input vector, but does not make any guarantees about algorithmically selected UTXOs. However, by design they will always be placed after the manually selected ones.